summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kolibs/KoPageLayoutColumns.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /kexi/3rdparty/kolibs/KoPageLayoutColumns.h
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'kexi/3rdparty/kolibs/KoPageLayoutColumns.h')
-rw-r--r--kexi/3rdparty/kolibs/KoPageLayoutColumns.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kexi/3rdparty/kolibs/KoPageLayoutColumns.h b/kexi/3rdparty/kolibs/KoPageLayoutColumns.h
index b9dcd6c2..8ebac1b2 100644
--- a/kexi/3rdparty/kolibs/KoPageLayoutColumns.h
+++ b/kexi/3rdparty/kolibs/KoPageLayoutColumns.h
@@ -43,15 +43,15 @@ public:
* @param parent the parent widget
* @param columns the KoColumns data structure that this dialog should be initialzed with
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param layout the page layout that the preview should be initialzed with.
*/
- KoPageLayoutColumns(TQWidget *parent, const KoColumns& columns, KoUnit::Unit unit, const KoPageLayout& layout);
+ KoPageLayoutColumns(TQWidget *parent, const KoColumns& columns, KoUnit::Unit unit, const KoPageLayout& tqlayout);
/**
* Update the page preview widget with the param layout.
* @param layout the new layout
*/
- void setLayout(KoPageLayout &layout);
+ void setLayout(KoPageLayout &tqlayout);
public slots:
/**
@@ -43,15 +43,15 @@ public:
* @param columns the KoColumns data structure that this dialog should be initialzed with
* @param unit the unit-type (mm/cm/inch) that the dialog should show
- * @param layout the page layout that the preview should be initialzed with.
+ * @param tqlayout the page tqlayout that the preview should be initialzed with.
*/
@@ -43,15 +43,15 @@ public:
/**
- * Update the page preview widget with the param layout.
- * @param layout the new layout
+ * Update the page preview widget with the param tqlayout.
+ * @param tqlayout the new tqlayout
*/